/*-------------------------------------------------------------------------------------------------------------+
|                                                                       |
|   Trigger: PARAM_FILIAL                                       |
|   Tabela: ParamFilial                                         |
|                                                               |
|   Descrio:                                                  |
|   Sincroniza os campos de Gerente Operacional, Supervisor e Quantidade        |
|   de Funcionrios entre as tabelas HISTFILIAL e FILIAL                        |
|                                                                               |
|   Criao:                                                                    |
|   18/01/2008 - Luiz Passos                                            |
|                                                                               |
+-------------------------------------------------------------------------------------------------------------*/

create or replace TRIGGER PARAM_FILIAL
AFTER INSERT OR UPDATE
OF DTPROCESSA ON PARAMFILIAL FOR EACH ROW
DECLARE   
  V_DTREFERHIST     HISTFILIAL.DTREFEHIST%TYPE;
  V_CDGOPERACHIST   HISTFILIAL.CDGOPERACHIST%TYPE;  
  V_CDSUPERVHIST    HISTFILIAL.CDSUPERVHIST%TYPE;
  V_QTFUNCFILIHIST  HISTFILIAL.QTFUNCFILIHIST%TYPE;  
  
  V_QTFUNCFILI    FILIAL.QTFUNCFILI%TYPE;
  V_CDGOPERAC     FILIAL.CDGOPERAC%TYPE;
  V_CDSUPERVISOR  FILIAL.CDSUPERVISOR%TYPE;
BEGIN
  IF :NEW.DTPROCESSA IS NOT NULL THEN
    BEGIN
      SELECT QTFUNCFILI, CDGOPERAC, CDSUPERVISOR
      INTO   V_QTFUNCFILI, V_CDGOPERAC, V_CDSUPERVISOR
      FROM   FILIAL
      WHERE  CDFILIAL = :OLD.CDFILIAL;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        V_QTFUNCFILI   := NULL;
        V_CDGOPERAC    := NULL;
        V_CDSUPERVISOR := NULL;      
    END; 
    
    BEGIN 
      SELECT  DTREFEHIST, CDGOPERACHIST, CDSUPERVHIST, QTFUNCFILIHIST
      INTO    V_DTREFERHIST, V_CDGOPERACHIST,  V_CDSUPERVHIST, V_QTFUNCFILIHIST
      FROM    HISTFILIAL 
      WHERE   TO_CHAR(DTREFEHIST, 'MMYYYY') = TO_CHAR(:NEW.DTPROCESSA,'MMYYYY') AND CDFILIAL = :NEW.CDFILIAL;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
          V_DTREFERHIST     := NULL;
          V_CDGOPERACHIST   := NULL;
          V_CDSUPERVHIST    := NULL;
          V_QTFUNCFILIHIST  := NULL;
    END;            
    
    IF V_DTREFERHIST IS NULL THEN 
      INSERT INTO HISTFILIAL
        (CDGOPERACHIST,
         CDSUPERVHIST,
         QTFUNCFILIHIST,
         DTREFEHIST,
         CDFILIAL)
      VALUES
        (V_CDGOPERAC,
         V_CDSUPERVISOR,
         V_QTFUNCFILI,
         TO_DATE('01'||TO_CHAR(:NEW.DTPROCESSA,'MMYYYY'),'DDMMYYYY'),
         :NEW.CDFILIAL);    
    ELSE 
      UPDATE FILIAL SET
        CDGOPERAC    = V_CDGOPERACHIST,                  
        CDSUPERVISOR = V_CDSUPERVHIST,
        QTFUNCFILI   = V_QTFUNCFILIHIST
      WHERE        
        CDFILIAL = :NEW.CDFILIAL;
    END IF;
  END IF;
  
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('PARAM_FILIAL','5.01.007'); END;
/



